@@ -1,5 +1,5 @@
-from network import fetch_html_from_fr24
-from scraper import parse_flights
+from myfr24.scraper import parse_flights
+from myfr24.network import fetch_html_from_fr24
 
 
 class MyFR24(object):
